* [PATCH v3 2/3] powerpc/fsl: 85xx: document cache-sram
From: Vivek Mahajan @ 2009-10-21 12:50 UTC (permalink / raw)
To: linuxppc-dev; +Cc: kumar.gala, Vivek Mahajan
In-Reply-To: <1256129459-10685-1-git-send-email-vivek.mahajan@freescale.com>
Adds documentation for Freescale's QorIQ based cache-sram as under:-
* How to enable it from a low level driver
* How to set its size
Signed-off-by: Vivek Mahajan <vivek.mahajan@freescale.com>
---
v2, v3: No change over v1
Documentation/powerpc/fsl_85xx_cache_sram.txt | 31 +++++++++++++++++++++++++
1 files changed, 31 insertions(+), 0 deletions(-)
create mode 100644 Documentation/powerpc/fsl_85xx_cache_sram.txt
diff --git a/Documentation/powerpc/fsl_85xx_cache_sram.txt b/Documentation/powerpc/fsl_85xx_cache_sram.txt
new file mode 100644
index 0000000..7f43e2a
--- /dev/null
+++ b/Documentation/powerpc/fsl_85xx_cache_sram.txt
@@ -0,0 +1,31 @@
+* Freescale QorIQ based Cache SRAM
+
+Freescale's QorIQ platforms provide an option of configuring
+a part of (or full) cache memory as SRAM. Any low level
+driver can use its APIs via selecting FSL_85XX_CACHE_SRAM as
+under for the case of gianfar ethernet driver:-
+
+In drivers/net/Kconfig:-
+
+config GIANFAR
+ ....
+ select FSL_85XX_CACHE_SRAM if MPC85xx
+ ....
+
+FSL_85XX_CACHE_SRAM and its base address are defined in
+arch/powerpc/platforms/85xx/Kconfig as under:-
+
+config FSL_85XX_CACHE_SRAM
+ bool
+ select PPC_LIB_RHEAP
+
+config FSL_85XX_CACHE_SRAM_BASE
+ hex
+ depends on FSL_85XX_CACHE_SRAM
+ default "0xfff00000"
+
+The size of the above cache SRAM memory window is passed via the
+kernel command line as <cache-sram-size=....>
+
+Absence of the above parameter in the kernel command line is
+treated as no cache SRAM.
--
1.5.6.5
^ permalink raw reply related
* [PATCH v3 3/3] powerpc/fsl: 85xx: add cache-sram support
From: Vivek Mahajan @ 2009-10-21 12:50 UTC (permalink / raw)
To: linuxppc-dev; +Cc: kumar.gala, Vivek Mahajan
In-Reply-To: <1256129459-10685-2-git-send-email-vivek.mahajan@freescale.com>
This adds QorIQ based Cache-SRAM support as under:-
* A small abstraction over powerpc's remote heap allocator
* Exports mpc85xx_cache_sram_alloc()/free() APIs
* Supports only one contiguous SRAM window
* Defines FSL_85XX_CACHE_SRAM and its base address
Signed-off-by: Vivek Mahajan <vivek.mahajan@freescale.com>
---
v2: mbar(1) -> eieio() as per Kumar G.
v3: Fixed cache-sram ways computation
arch/powerpc/include/asm/fsl_85xx_cache_sram.h | 48 ++++++
arch/powerpc/platforms/85xx/Kconfig | 9 ++
arch/powerpc/sysdev/Makefile | 1 +
arch/powerpc/sysdev/fsl_85xx_cache_ctlr.h | 95 ++++++++++++
arch/powerpc/sysdev/fsl_85xx_cache_sram.c | 141 ++++++++++++++++++
arch/powerpc/sysdev/fsl_85xx_l2ctlr.c | 184 ++++++++++++++++++++++++
6 files changed, 478 insertions(+), 0 deletions(-)
create mode 100644 arch/powerpc/include/asm/fsl_85xx_cache_sram.h
create mode 100644 arch/powerpc/sysdev/fsl_85xx_cache_ctlr.h
create mode 100644 arch/powerpc/sysdev/fsl_85xx_cache_sram.c
create mode 100644 arch/powerpc/sysdev/fsl_85xx_l2ctlr.c
diff --git a/arch/powerpc/include/asm/fsl_85xx_cache_sram.h b/arch/powerpc/include/asm/fsl_85xx_cache_sram.h
new file mode 100644
index 0000000..2af2bdc
--- /dev/null
+++ b/arch/powerpc/include/asm/fsl_85xx_cache_sram.h
@@ -0,0 +1,48 @@
+/*
+ * Copyright 2009 Freescale Semiconductor, Inc.
+ *
+ * Cache SRAM handling for QorIQ platform
+ *
+ * Author: Vivek Mahajan <vivek.mahajan@freescale.com>
+
+ * This file is derived from the original work done
+ * by Sylvain Munaut for the Bestcomm SRAM allocator.
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation; either version 2 of the License, or (at your
+ * option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
+#ifndef __ASM_POWERPC_FSL_85XX_CACHE_SRAM_H__
+#define __ASM_POWERPC_FSL_85XX_CACHE_SRAM_H__
+
+#include <asm/rheap.h>
+#include <linux/spinlock.h>
+
+/*
+ * Cache-SRAM
+ */
+
+struct mpc85xx_cache_sram {
+ phys_addr_t base_phys;
+ void *base_virt;
+ unsigned int size;
+ rh_info_t *rh;
+ spinlock_t lock;
+};
+
+extern void mpc85xx_cache_sram_free(void *ptr);
+extern void *mpc85xx_cache_sram_alloc(unsigned int size,
+ phys_addr_t *phys, unsigned int align);
+
+#endif /* __AMS_POWERPC_FSL_85XX_CACHE_SRAM_H__ */
diff --git a/arch/powerpc/platforms/85xx/Kconfig b/arch/powerpc/platforms/85xx/Kconfig
index d3a975e..b6f23c3 100644
--- a/arch/powerpc/platforms/85xx/Kconfig
+++ b/arch/powerpc/platforms/85xx/Kconfig
@@ -144,6 +144,15 @@ config SBC8560
help
This option enables support for the Wind River SBC8560 board
+config FSL_85XX_CACHE_SRAM
+ bool
+ select PPC_LIB_RHEAP
+
+config FSL_85XX_CACHE_SRAM_BASE
+ hex
+ depends on FSL_85XX_CACHE_SRAM
+ default "0xfff00000"
+
endif # MPC85xx
config TQM85xx
diff --git a/arch/powerpc/sysdev/Makefile b/arch/powerpc/sysdev/Makefile
index 9d4b174..745994c 100644
--- a/arch/powerpc/sysdev/Makefile
+++ b/arch/powerpc/sysdev/Makefile
@@ -19,6 +19,7 @@ obj-$(CONFIG_FSL_PCI) += fsl_pci.o $(fsl-msi-obj-y)
obj-$(CONFIG_FSL_LBC) += fsl_lbc.o
obj-$(CONFIG_FSL_GTM) += fsl_gtm.o
obj-$(CONFIG_MPC8xxx_GPIO) += mpc8xxx_gpio.o
+obj-$(CONFIG_FSL_85XX_CACHE_SRAM) += fsl_85xx_l2ctlr.o fsl_85xx_cache_sram.o
obj-$(CONFIG_SIMPLE_GPIO) += simple_gpio.o
obj-$(CONFIG_RAPIDIO) += fsl_rio.o
obj-$(CONFIG_TSI108_BRIDGE) += tsi108_pci.o tsi108_dev.o
diff --git a/arch/powerpc/sysdev/fsl_85xx_cache_ctlr.h b/arch/powerpc/sysdev/fsl_85xx_cache_ctlr.h
new file mode 100644
index 0000000..8c4a4ac
--- /dev/null
+++ b/arch/powerpc/sysdev/fsl_85xx_cache_ctlr.h
@@ -0,0 +1,95 @@
+/*
+ * Copyright 2009 Freescale Semiconductor, Inc
+ *
+ * QorIQ based Cache Controller Memory Mapped Registers
+ *
+ * Author: Vivek Mahajan <vivek.mahajan@freescale.com>
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation; either version 2 of the License, or (at your
+ * option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
+#ifndef __FSL_85XX_CACHE_CTLR_H__
+#define __FSL_85XX_CACHE_CTLR_H__
+
+#define L2CR_L2FI 0x40000000 /* L2 flash invalidate */
+#define L2CR_L2IO 0x00200000 /* L2 instruction only */
+#define L2CR_SRAM_ZERO 0x00000000 /* L2SRAM zero size */
+#define L2CR_SRAM_FULL 0x00010000 /* L2SRAM full size */
+#define L2CR_SRAM_HALF 0x00020000 /* L2SRAM half size */
+#define L2CR_SRAM_TWO_HALFS 0x00030000 /* L2SRAM two half sizes */
+#define L2CR_SRAM_QUART 0x00040000 /* L2SRAM one quarter size */
+#define L2CR_SRAM_TWO_QUARTS 0x00050000 /* L2SRAM two quarter size */
+#define L2CR_SRAM_EIGHTH 0x00060000 /* L2SRAM one eighth size */
+#define L2CR_SRAM_TWO_EIGHTH 0x00070000 /* L2SRAM two eighth size */
+
+#define L2SRAM_OPTIMAL_SZ_SHIFT 0x00000003 /* Optimum size for L2SRAM */
+
+#define L2SRAM_BAR_MSK_LO18 0xFFFFC000 /* Lower 18 bits */
+#define L2SRAM_BARE_MSK_HI4 0x0000000F /* Upper 4 bits */
+
+enum cache_sram_lock_ways {
+ LOCK_WAYS_ZERO,
+ LOCK_WAYS_EIGHTH,
+ LOCK_WAYS_TWO_EIGHTH,
+ LOCK_WAYS_HALF = 4,
+ LOCK_WAYS_FULL = 8,
+};
+
+struct mpc85xx_l2ctlr {
+ u32 ctl; /* 0x000 - L2 control */
+ u8 res1[0xC];
+ u32 ewar0; /* 0x010 - External write address 0 */
+ u32 ewarea0; /* 0x014 - External write address extended 0 */
+ u32 ewcr0; /* 0x018 - External write ctrl */
+ u8 res2[4];
+ u32 ewar1; /* 0x020 - External write address 1 */
+ u32 ewarea1; /* 0x024 - External write address extended 1 */
+ u32 ewcr1; /* 0x028 - External write ctrl 1 */
+ u8 res3[4];
+ u32 ewar2; /* 0x030 - External write address 2 */
+ u32 ewarea2; /* 0x034 - External write address extended 2 */
+ u32 ewcr2; /* 0x038 - External write ctrl 2 */
+ u8 res4[4];
+ u32 ewar3; /* 0x040 - External write address 3 */
+ u32 ewarea3; /* 0x044 - External write address extended 3 */
+ u32 ewcr3; /* 0x048 - External write ctrl 3 */
+ u8 res5[0xB4];
+ u32 srbar0; /* 0x100 - SRAM base address 0 */
+ u32 srbarea0; /* 0x104 - SRAM base addr reg ext address 0 */
+ u32 srbar1; /* 0x108 - SRAM base address 1 */
+ u32 srbarea1; /* 0x10C - SRAM base addr reg ext address 1 */
+ u8 res6[0xCF0];
+ u32 errinjhi; /* 0xE00 - Error injection mask high */
+ u32 errinjlo; /* 0xE04 - Error injection mask low */
+ u32 errinjctl; /* 0xE08 - Error injection tag/ecc control */
+ u8 res7[0x14];
+ u32 captdatahi; /* 0xE20 - Error data high capture */
+ u32 captdatalo; /* 0xE24 - Error data low capture */
+ u32 captecc; /* 0xE28 - Error syndrome */
+ u8 res8[0x14];
+ u32 errdet; /* 0xE40 - Error detect */
+ u32 errdis; /* 0xE44 - Error disable */
+ u32 errinten; /* 0xE48 - Error interrupt enable */
+ u32 errattr; /* 0xE4c - Error attribute capture */
+ u32 erradrrl; /* 0xE50 - Error address capture low */
+ u32 erradrrh; /* 0xE54 - Error address capture high */
+ u32 errctl; /* 0xE58 - Error control */
+ u8 res9[0x1A4];
+};
+
+extern int instantiate_cache_sram(struct of_device *dev, unsigned int size);
+extern void remove_cache_sram(struct of_device *dev);
+
+#endif /* __FSL_85XX_CACHE_CTLR_H__ */
diff --git a/arch/powerpc/sysdev/fsl_85xx_cache_sram.c b/arch/powerpc/sysdev/fsl_85xx_cache_sram.c
new file mode 100644
index 0000000..6744083
--- /dev/null
+++ b/arch/powerpc/sysdev/fsl_85xx_cache_sram.c
@@ -0,0 +1,141 @@
+/*
+ * Copyright 2009 Freescale Semiconductor, Inc.
+ *
+ * Simple memory allocator abstraction for QorIQ (P1/P2) based Cache-SRAM
+ *
+ * Author: Vivek Mahajan <vivek.mahajan@freescale.com>
+ *
+ * This file is derived from the original work done
+ * by Sylvain Munaut for the Bestcomm SRAM allocator.
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation; either version 2 of the License, or (at your
+ * option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
+#include <linux/kernel.h>
+#include <linux/of_platform.h>
+#include <asm/pgtable.h>
+#include <asm/fsl_85xx_cache_sram.h>
+
+struct mpc85xx_cache_sram *cache_sram;
+
+void *mpc85xx_cache_sram_alloc(unsigned int size,
+ phys_addr_t *phys, unsigned int align)
+{
+ unsigned long offset;
+ unsigned long flags;
+
+ if (!size || (size > cache_sram->size) || (align > cache_sram->size)) {
+ pr_err("%s(): size(=%x) or align(=%x) zero or too big\n",
+ __func__, size, align);
+ return NULL;
+ }
+
+ if ((align & (align - 1)) || align <= 1) {
+ pr_err("%s(): align(=%x) must be power of two and >1\n",
+ __func__, align);
+ return NULL;
+ }
+
+ spin_lock_irqsave(&cache_sram->lock, flags);
+ offset = rh_alloc_align(cache_sram->rh, size, align, NULL);
+ spin_unlock_irqrestore(&cache_sram->lock, flags);
+
+ if (IS_ERR_VALUE(offset))
+ return NULL;
+
+ *phys = cache_sram->base_phys + offset;
+
+ return (unsigned char *)cache_sram->base_virt + offset;
+}
+EXPORT_SYMBOL(mpc85xx_cache_sram_alloc);
+
+void mpc85xx_cache_sram_free(void *ptr)
+{
+ unsigned long flags;
+ BUG_ON(!ptr);
+
+ spin_lock_irqsave(&cache_sram->lock, flags);
+ rh_free(cache_sram->rh, ptr - cache_sram->base_virt);
+ spin_unlock_irqrestore(&cache_sram->lock, flags);
+}
+EXPORT_SYMBOL(mpc85xx_cache_sram_free);
+
+int __init instantiate_cache_sram(struct of_device *dev, unsigned int size)
+{
+ if (cache_sram) {
+ dev_err(&dev->dev, "Already initialized cache-sram\n");
+ return -EBUSY;
+ }
+
+ cache_sram = kzalloc(sizeof(struct mpc85xx_cache_sram), GFP_KERNEL);
+ if (!cache_sram) {
+ dev_err(&dev->dev, "Out of memory for cache_sram structure\n");
+ return -ENOMEM;
+ }
+
+ cache_sram->base_phys = CONFIG_FSL_85XX_CACHE_SRAM_BASE;
+ cache_sram->size = size;
+
+ if (!request_mem_region(cache_sram->base_phys, cache_sram->size,
+ "fsl_85xx_cache_sram")) {
+ dev_err(&dev->dev, "%s: request memory failed\n",
+ dev->node->full_name);
+ kfree(cache_sram);
+ return -ENXIO;
+ }
+
+ cache_sram->base_virt = ioremap_flags(cache_sram->base_phys,
+ cache_sram->size, _PAGE_COHERENT | PAGE_KERNEL);
+ if (!cache_sram->base_virt) {
+ dev_err(&dev->dev, "%s: ioremap_flags failed\n",
+ dev->node->full_name);
+ release_mem_region(cache_sram->base_phys, cache_sram->size);
+ kfree(cache_sram);
+ return -ENOMEM;
+ }
+
+ cache_sram->rh = rh_create(sizeof(unsigned int));
+ if (IS_ERR(cache_sram->rh)) {
+ dev_err(&dev->dev, "%s: Unable to create remote heap\n",
+ dev->node->full_name);
+ iounmap(cache_sram->base_virt);
+ release_mem_region(cache_sram->base_phys, cache_sram->size);
+ kfree(cache_sram);
+ return PTR_ERR(cache_sram->rh);
+ }
+
+ rh_attach_region(cache_sram->rh, 0, cache_sram->size);
+ spin_lock_init(&cache_sram->lock);
+
+ dev_info(&dev->dev, "[base:0x%x, size:0x%x] configured and loaded\n",
+ cache_sram->base_phys, cache_sram->size);
+ return 0;
+}
+
+void remove_cache_sram(struct of_device *dev)
+{
+ BUG_ON(!cache_sram);
+
+ rh_detach_region(cache_sram->rh, 0, cache_sram->size);
+ rh_destroy(cache_sram->rh);
+
+ iounmap(cache_sram->base_virt);
+ release_mem_region(cache_sram->base_phys, cache_sram->size);
+
+ kfree(cache_sram);
+ cache_sram = NULL;
+
+ dev_info(&dev->dev, "MPC85xx Cache-SRAM driver unloaded\n");
+}
diff --git a/arch/powerpc/sysdev/fsl_85xx_l2ctlr.c b/arch/powerpc/sysdev/fsl_85xx_l2ctlr.c
new file mode 100644
index 0000000..c851547
--- /dev/null
+++ b/arch/powerpc/sysdev/fsl_85xx_l2ctlr.c
@@ -0,0 +1,184 @@
+/*
+ * Copyright 2009 Freescale Semiconductor, Inc.
+ *
+ * QorIQ (P1/P2) L2 controller init for Cache-SRAM instantiation
+ *
+ * Author: Vivek Mahajan <vivek.mahajan@freescale.com>
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation; either version 2 of the License, or (at your
+ * option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
+#include <linux/kernel.h>
+#include <linux/of_platform.h>
+#include <asm/io.h>
+
+#include "fsl_85xx_cache_ctlr.h"
+
+static char *param;
+struct mpc85xx_l2ctlr __iomem *l2ctlr;
+
+static long get_cache_sram_size(void)
+{
+ unsigned long val;
+
+ if (!param || (strict_strtoul(param, 0, &val) < 0))
+ return -EINVAL;
+
+ return val;
+}
+
+static int __init get_cmdline_param(char *str)
+{
+ if (!str)
+ return 0;
+
+ param = str;
+ return 1;
+}
+
+__setup("cache-sram-size=", get_cmdline_param);
+
+static int __devinit mpc85xx_l2ctlr_of_probe(struct of_device *dev,
+ const struct of_device_id *match)
+{
+ long rval;
+ unsigned int rem;
+ unsigned char ways;
+ const unsigned int *prop;
+ unsigned int l2cache_size;
+ unsigned int sram_size;
+
+ if (!dev->node) {
+ dev_err(&dev->dev, "Device's OF-node is NULL\n");
+ return -EINVAL;
+ }
+
+ prop = of_get_property(dev->node, "cache-size", NULL);
+ if (!prop) {
+ dev_err(&dev->dev, "Missing L2 cache-size\n");
+ return -EINVAL;
+ }
+ l2cache_size = *prop;
+
+ rval = get_cache_sram_size();
+ if (rval <= 0) {
+ dev_err(&dev->dev,
+ "Entire L2 as cache, Aborting Cache-SRAM stuff\n");
+ return -EINVAL;
+ }
+
+ rem = l2cache_size % (unsigned int)rval;
+ ways = LOCK_WAYS_FULL * (unsigned int)rval / l2cache_size;
+ if (rem || (ways & (ways - 1))) {
+ dev_err(&dev->dev, "Illegal cache-sram-size in command line\n");
+ return -EINVAL;
+ }
+
+ sram_size = (unsigned int)rval;
+
+ l2ctlr = of_iomap(dev->node, 0);
+ if (!l2ctlr) {
+ dev_err(&dev->dev, "Can't map L2 controller\n");
+ return -EINVAL;
+ }
+
+ /*
+ * Write bits[0-17] to srbar0
+ */
+ out_be32(&l2ctlr->srbar0,
+ CONFIG_FSL_85XX_CACHE_SRAM_BASE & L2SRAM_BAR_MSK_LO18);
+
+ /*
+ * Write bits[18-21] to srbare0
+ */
+ out_be32(&l2ctlr->srbarea0,
+ (CONFIG_FSL_85XX_CACHE_SRAM_BASE >> 10) & L2SRAM_BARE_MSK_HI4);
+
+ clrsetbits_be32(&l2ctlr->ctl, L2CR_L2E, L2CR_L2FI);
+
+ switch (ways) {
+ case LOCK_WAYS_EIGHTH:
+ setbits32(&l2ctlr->ctl,
+ L2CR_L2E | L2CR_L2FI | L2CR_SRAM_EIGHTH);
+ break;
+
+ case LOCK_WAYS_TWO_EIGHTH:
+ setbits32(&l2ctlr->ctl,
+ L2CR_L2E | L2CR_L2FI | L2CR_SRAM_QUART);
+ break;
+
+ case LOCK_WAYS_HALF:
+ setbits32(&l2ctlr->ctl,
+ L2CR_L2E | L2CR_L2FI | L2CR_SRAM_HALF);
+ break;
+
+ case LOCK_WAYS_FULL:
+ default:
+ setbits32(&l2ctlr->ctl,
+ L2CR_L2E | L2CR_L2FI | L2CR_SRAM_FULL);
+ break;
+ }
+ eieio();
+
+ rval = instantiate_cache_sram(dev, sram_size);
+ if (rval < 0) {
+ dev_err(&dev->dev, "Can't instantiate Cache-SRAM\n");
+ iounmap(l2ctlr);
+ return -EINVAL;
+ }
+
+ return 0;
+}
+
+static int __devexit mpc85xx_l2ctlr_of_remove(struct of_device *dev)
+{
+ BUG_ON(!l2ctlr);
+
+ iounmap(l2ctlr);
+ remove_cache_sram(dev);
+ dev_info(&dev->dev, "MPC85xx L2 controller unloaded\n");
+
+ return 0;
+}
+
+static struct of_device_id mpc85xx_l2ctlr_of_match[] = {
+ {
+ .compatible = "fsl,p2020-l2-cache-controller",
+ },
+ {},
+};
+
+static struct of_platform_driver mpc85xx_l2ctlr_of_platform_driver = {
+ .name = "fsl-l2ctlr",
+ .match_table = mpc85xx_l2ctlr_of_match,
+ .probe = mpc85xx_l2ctlr_of_probe,
+ .remove = __devexit_p(mpc85xx_l2ctlr_of_remove),
+};
+
+static __init int mpc85xx_l2ctlr_of_init(void)
+{
+ return of_register_platform_driver(&mpc85xx_l2ctlr_of_platform_driver);
+}
+
+static void __exit mpc85xx_l2ctlr_of_exit(void)
+{
+ of_unregister_platform_driver(&mpc85xx_l2ctlr_of_platform_driver);
+}
+
+subsys_initcall(mpc85xx_l2ctlr_of_init);
+module_exit(mpc85xx_l2ctlr_of_exit);
+
+MODULE_DESCRIPTION("Freescale MPC85xx L2 controller init");
+MODULE_LICENSE("GPL v2");
--
1.5.6.5
^ permalink raw reply related
* Re: [PATCH v4] powerpc/5200: Add mpc5200-spi (non-PSC) device driver
From: Wolfram Sang @ 2009-10-21 13:17 UTC (permalink / raw)
To: Grant Likely
Cc: linuxppc-dev, David Brownell, linux-kernel, spi-devel-general
In-Reply-To: <20090618025030.12363.69402.stgit@localhost.localdomain>
[-- Attachment #1: Type: text/plain, Size: 535 bytes --]
Hi Grant,
On Wed, Jun 17, 2009 at 08:55:01PM -0600, Grant Likely wrote:
> From: Grant Likely <grant.likely@secretlab.ca>
>
> Adds support for the dedicated SPI device on the Freescale MPC5200(b)
> SoC.
>
> Signed-off-by: Grant Likely <grant.likely@secretlab.ca>
do you have an updated version to share? Or is V4 still 'status quo'?
Genki de ;)
Wolfram
--
Pengutronix e.K. | Wolfram Sang |
Industrial Linux Solutions | http://www.pengutronix.de/ |
[-- Attachment #2: Digital signature --]
[-- Type: application/pgp-signature, Size: 197 bytes --]
^ permalink raw reply
* Re: Linux for MPC5554 or MPC5534 (core e200z6)?
From: Kumar Gala @ 2009-10-21 14:04 UTC (permalink / raw)
To: Németh Márton; +Cc: linuxppc-dev
In-Reply-To: <4ADE37DC.4070909@freemail.hu>
On Oct 20, 2009, at 5:21 PM, N=E9meth M=E1rton wrote:
> Hi Grant,
> Hello List,
>
> is there anybody who was successfully run Linux kernel on Freescale =20=
> MPC5554
> [1], [2] or on Freescale MPC5534 [3], [4]? Both of these embedded =20
> PowerPC
> controllers have the e200z6 core.
>
> Is there anybody who is working with these controllers or with the =20
> e200z6 core?
>
> References:
> [1] Freescale MPC5554
> =
http://www.freescale.com/webapp/sps/site/prod_summary.jsp?code=3DMPC5554
>
> [2] MPC5553/MPC5554 Microcontroller Reference Manual
> =
http://www.freescale.com/files/32bit/doc/ref_manual/MPC5553_MPC5554_RM.pdf=
>
> [3] Freescale MPC5534
> http://www.freescale.com/webapp/sps/site/prod_summary.jsp?code=3DMPC5534=
>
> [4] MPC5534 Microcontroller Reference Manual
> http://www.freescale.com/files/32bit/doc/ref_manual/MPC5534RM.pdf
I'm not aware of anyone working on Linux for these chips based on the =20=
e200z6. What application do you have that you want to run Linux on =20
them?
- k=
^ permalink raw reply
* Re: Linux for MPC5554 or MPC5534 (core e200z6)?
From: Grant Likely @ 2009-10-21 14:13 UTC (permalink / raw)
To: Németh Márton; +Cc: linuxppc-dev
In-Reply-To: <4ADE37DC.4070909@freemail.hu>
2009/10/21 N=E9meth M=E1rton <nm127@freemail.hu>:
> Hi Grant,
> Hello List,
>
> is there anybody who was successfully run Linux kernel on Freescale MPC55=
54
> [1], [2] or on Freescale MPC5534 [3], [4]? Both of these embedded PowerPC
> controllers have the e200z6 core.
>
> Is there anybody who is working with these controllers or with the e200z6=
core?
I'm pretty sure nobody has done a Linux port to any of these chips.
Nor do I know of any work having been done in the past.
g.
--=20
Grant Likely, B.Sc., P.Eng.
Secret Lab Technologies Ltd.
^ permalink raw reply
* [PATCH 0/5 v4] Kernel Handling of Dynamic Logical Partitioning
From: Nathan Fontenot @ 2009-10-21 14:35 UTC (permalink / raw)
To: linuxppc-dev; +Cc: lkml
This is a re-send of the entire patch set with updates made from the comments
I have received, namely patches 1,3 and 5. I am re-sending the entire patch
set for clarity.
The Dynamic Logical Partitioning (DLPAR) capabilities of the powerpc pseries
platform allows for the addition and removal of resources (i.e. cpus,
memory, pci devices) from a partition. The removal of a resource involves
removing the resource's node from the device tree and then returning the
resource to firmware via the rtas set-indicator call. To add a resource, it
is first obtained from firmware via the rtas set-indicator call and then a
new device tree node is created using the ibm,configure-coinnector rtas call
and added to the device tree.
The following set of patches implements the needed infrastructure to have the
kernel handle the DLPAR addition and removal of memory and cpus (other
DLPAR'able items to follow in future patches). The framework for this is
to create a set of probe/release sysfs files in pseries that will add or
remove the cpu or memory to the system.
The majority of the code is powerpc/pseries specific except for PATCH 3/5, so
I am cc'ing lkml.
Patches include in this set:
1/5 - DLPAR infracstructure for powerpc/pseries platform.
2/5 - Move the of_drconf_cell struct to prom.h
3/5 - Export the memory sysdev class
4/5 - Memory DLPAR handling
5/5 - CPU DLPAR handling
-Nathan Fontenot
^ permalink raw reply
* [PATCH 1/5 v4] Kernel Handling of Dynamic Logical Partitioning
From: Nathan Fontenot @ 2009-10-21 14:40 UTC (permalink / raw)
To: linuxppc-dev; +Cc: linux-kernel
In-Reply-To: <4ADF1C49.2030201@austin.ibm.com>
This patch provides the kernel DLPAR infrastructure in a new filed named
dlpar.c. The functionality provided is for acquiring and releasing a
resource from firmware and the parsing of information returned from the
ibm,configure-connector rtas call. Additionally this exports the
pSeries reconfiguration notifier chain so that it can be invoked when
device tree updates are made.
Signed-off-by: Nathan Fontenot <nfont at austin.ibm.com>
---
Index: powerpc/arch/powerpc/platforms/pseries/dlpar.c
===================================================================
--- /dev/null 1970-01-01 00:00:00.000000000 +0000
+++ powerpc/arch/powerpc/platforms/pseries/dlpar.c 2009-10-19 11:59:10.000000000 -0500
@@ -0,0 +1,414 @@
+/*
+ * dlpar.c - support for dynamic reconfiguration (including PCI
+ * Hotplug and Dynamic Logical Partitioning on RPA platforms).
+ *
+ * Copyright (C) 2009 Nathan Fontenot
+ * Copyright (C) 2009 IBM Corporation
+ *
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License version
+ * 2 as published by the Free Software Foundation.
+ */
+
+#include <linux/kernel.h>
+#include <linux/kref.h>
+#include <linux/notifier.h>
+#include <linux/proc_fs.h>
+#include <linux/spinlock.h>
+
+#include <asm/prom.h>
+#include <asm/machdep.h>
+#include <asm/uaccess.h>
+#include <asm/rtas.h>
+#include <asm/pSeries_reconfig.h>
+
+#define CFG_CONN_WORK_SIZE 4096
+static char workarea[CFG_CONN_WORK_SIZE];
+static DEFINE_SPINLOCK(workarea_lock);
+
+struct cc_workarea {
+ u32 drc_index;
+ u32 zero;
+ u32 name_offset;
+ u32 prop_length;
+ u32 prop_offset;
+};
+
+static struct property *parse_cc_property(char *workarea)
+{
+ struct property *prop;
+ struct cc_workarea *ccwa;
+ char *name;
+ char *value;
+
+ prop = kzalloc(sizeof(*prop), GFP_KERNEL);
+ if (!prop)
+ return NULL;
+
+ ccwa = (struct cc_workarea *)workarea;
+ name = workarea + ccwa->name_offset;
+ prop->name = kzalloc(strlen(name) + 1, GFP_KERNEL);
+ if (!prop->name) {
+ kfree(prop);
+ return NULL;
+ }
+
+ strcpy(prop->name, name);
+
+ prop->length = ccwa->prop_length;
+ value = workarea + ccwa->prop_offset;
+ prop->value = kzalloc(prop->length, GFP_KERNEL);
+ if (!prop->value) {
+ kfree(prop->name);
+ kfree(prop);
+ return NULL;
+ }
+
+ memcpy(prop->value, value, prop->length);
+ return prop;
+}
+
+static void free_property(struct property *prop)
+{
+ kfree(prop->name);
+ kfree(prop->value);
+ kfree(prop);
+}
+
+static struct device_node *parse_cc_node(char *work_area)
+{
+ struct device_node *dn;
+ struct cc_workarea *ccwa;
+ char *name;
+
+ dn = kzalloc(sizeof(*dn), GFP_KERNEL);
+ if (!dn)
+ return NULL;
+
+ ccwa = (struct cc_workarea *)work_area;
+ name = work_area + ccwa->name_offset;
+ dn->full_name = kzalloc(strlen(name) + 1, GFP_KERNEL);
+ if (!dn->full_name) {
+ kfree(dn);
+ return NULL;
+ }
+
+ strcpy(dn->full_name, name);
+ return dn;
+}
+
+static void free_one_cc_node(struct device_node *dn)
+{
+ struct property *prop;
+
+ while (dn->properties) {
+ prop = dn->properties;
+ dn->properties = prop->next;
+ free_property(prop);
+ }
+
+ kfree(dn->full_name);
+ kfree(dn);
+}
+
+static void free_cc_nodes(struct device_node *dn)
+{
+ if (dn->child)
+ free_cc_nodes(dn->child);
+
+ if (dn->sibling)
+ free_cc_nodes(dn->sibling);
+
+ free_one_cc_node(dn);
+}
+
+#define NEXT_SIBLING 1
+#define NEXT_CHILD 2
+#define NEXT_PROPERTY 3
+#define PREV_PARENT 4
+#define MORE_MEMORY 5
+#define CALL_AGAIN -2
+#define ERR_CFG_USE -9003
+
+struct device_node *configure_connector(u32 drc_index)
+{
+ struct device_node *dn;
+ struct device_node *first_dn = NULL;
+ struct device_node *last_dn = NULL;
+ struct property *property;
+ struct property *last_property = NULL;
+ struct cc_workarea *ccwa;
+ int cc_token;
+ int rc;
+
+ cc_token = rtas_token("ibm,configure-connector");
+ if (cc_token == RTAS_UNKNOWN_SERVICE)
+ return NULL;
+
+ spin_lock(&workarea_lock);
+
+ ccwa = (struct cc_workarea *)&workarea[0];
+ ccwa->drc_index = drc_index;
+ ccwa->zero = 0;
+
+ rc = rtas_call(cc_token, 2, 1, NULL, workarea, NULL);
+ while (rc) {
+ switch (rc) {
+ case NEXT_SIBLING:
+ dn = parse_cc_node(workarea);
+ if (!dn)
+ goto cc_error;
+
+ dn->parent = last_dn->parent;
+ last_dn->sibling = dn;
+ last_dn = dn;
+ break;
+
+ case NEXT_CHILD:
+ dn = parse_cc_node(workarea);
+ if (!dn)
+ goto cc_error;
+
+ if (!first_dn)
+ first_dn = dn;
+ else {
+ dn->parent = last_dn;
+ if (last_dn)
+ last_dn->child = dn;
+ }
+
+ last_dn = dn;
+ break;
+
+ case NEXT_PROPERTY:
+ property = parse_cc_property(workarea);
+ if (!property)
+ goto cc_error;
+
+ if (!last_dn->properties)
+ last_dn->properties = property;
+ else
+ last_property->next = property;
+
+ last_property = property;
+ break;
+
+ case PREV_PARENT:
+ last_dn = last_dn->parent;
+ break;
+
+ case CALL_AGAIN:
+ break;
+
+ case MORE_MEMORY:
+ case ERR_CFG_USE:
+ default:
+ printk(KERN_ERR "Unexpected Error (%d) "
+ "returned from configure-connector\n", rc);
+ goto cc_error;
+ }
+
+ rc = rtas_call(cc_token, 2, 1, NULL, workarea, NULL);
+ }
+
+ spin_unlock(&workarea_lock);
+ return first_dn;
+
+cc_error:
+ spin_unlock(&workarea_lock);
+
+ if (first_dn)
+ free_cc_nodes(first_dn);
+
+ return NULL;
+}
+
+static struct device_node *derive_parent(const char *path)
+{
+ struct device_node *parent;
+ char parent_path[128];
+ int parent_path_len;
+
+ parent_path_len = strrchr(path, '/') - path + 1;
+ strlcpy(parent_path, path, parent_path_len);
+
+ parent = of_find_node_by_path(parent_path);
+
+ return parent;
+}
+
+static int add_one_node(struct device_node *dn)
+{
+ struct proc_dir_entry *ent;
+ int rc;
+
+ of_node_set_flag(dn, OF_DYNAMIC);
+ kref_init(&dn->kref);
+ dn->parent = derive_parent(dn->full_name);
+
+ rc = blocking_notifier_call_chain(&pSeries_reconfig_chain,
+ PSERIES_RECONFIG_ADD, dn);
+ if (rc == NOTIFY_BAD) {
+ printk(KERN_ERR "Failed to add device node %s\n",
+ dn->full_name);
+ return -ENOMEM; /* For now, safe to assume kmalloc failure */
+ }
+
+ of_attach_node(dn);
+
+#ifdef CONFIG_PROC_DEVICETREE
+ ent = proc_mkdir(strrchr(dn->full_name, '/') + 1, dn->parent->pde);
+ if (ent)
+ proc_device_tree_add_node(dn, ent);
+#endif
+
+ of_node_put(dn->parent);
+ return 0;
+}
+
+int add_device_tree_nodes(struct device_node *dn)
+{
+ struct device_node *child = dn->child;
+ struct device_node *sibling = dn->sibling;
+ int rc;
+
+ dn->child = NULL;
+ dn->sibling = NULL;
+ dn->parent = NULL;
+
+ rc = add_one_node(dn);
+ if (rc)
+ return rc;
+
+ if (child) {
+ rc = add_device_tree_nodes(child);
+ if (rc)
+ return rc;
+ }
+
+ if (sibling)
+ rc = add_device_tree_nodes(sibling);
+
+ return rc;
+}
+
+static int remove_one_node(struct device_node *dn)
+{
+ struct device_node *parent = dn->parent;
+ struct property *prop = dn->properties;
+
+#ifdef CONFIG_PROC_DEVICETREE
+ while (prop) {
+ remove_proc_entry(prop->name, dn->pde);
+ prop = prop->next;
+ }
+
+ if (dn->pde)
+ remove_proc_entry(dn->pde->name, parent->pde);
+#endif
+
+ blocking_notifier_call_chain(&pSeries_reconfig_chain,
+ PSERIES_RECONFIG_REMOVE, dn);
+ of_detach_node(dn);
+ of_node_put(dn); /* Must decrement the refcount */
+
+ return 0;
+}
+
+static int _remove_device_tree_nodes(struct device_node *dn)
+{
+ int rc;
+
+ if (dn->child) {
+ rc = _remove_device_tree_nodes(dn->child);
+ if (rc)
+ return rc;
+ }
+
+ if (dn->sibling) {
+ rc = _remove_device_tree_nodes(dn->sibling);
+ if (rc)
+ return rc;
+ }
+
+ rc = remove_one_node(dn);
+ return rc;
+}
+
+int remove_device_tree_nodes(struct device_node *dn)
+{
+ int rc;
+
+ if (dn->child) {
+ rc = _remove_device_tree_nodes(dn->child);
+ if (rc)
+ return rc;
+ }
+
+ rc = remove_one_node(dn);
+ return rc;
+}
+
+#define DR_ENTITY_SENSE 9003
+#define DR_ENTITY_PRESENT 1
+#define DR_ENTITY_UNUSABLE 2
+#define ALLOCATION_STATE 9003
+#define ALLOC_UNUSABLE 0
+#define ALLOC_USABLE 1
+#define ISOLATION_STATE 9001
+#define ISOLATE 0
+#define UNISOLATE 1
+
+int acquire_drc(u32 drc_index)
+{
+ int dr_status, rc;
+
+ rc = rtas_call(rtas_token("get-sensor-state"), 2, 2, &dr_status,
+ DR_ENTITY_SENSE, drc_index);
+ if (rc || dr_status != DR_ENTITY_UNUSABLE)
+ return -1;
+
+ rc = rtas_set_indicator(ALLOCATION_STATE, drc_index, ALLOC_USABLE);
+ if (rc)
+ return rc;
+
+ rc = rtas_set_indicator(ISOLATION_STATE, drc_index, UNISOLATE);
+ if (rc) {
+ rtas_set_indicator(ALLOCATION_STATE, drc_index, ALLOC_UNUSABLE);
+ return rc;
+ }
+
+ return 0;
+}
+
+int release_drc(u32 drc_index)
+{
+ int dr_status, rc;
+
+ rc = rtas_call(rtas_token("get-sensor-state"), 2, 2, &dr_status,
+ DR_ENTITY_SENSE, drc_index);
+ if (rc || dr_status != DR_ENTITY_PRESENT)
+ return -1;
+
+ rc = rtas_set_indicator(ISOLATION_STATE, drc_index, ISOLATE);
+ if (rc)
+ return rc;
+
+ rc = rtas_set_indicator(ALLOCATION_STATE, drc_index, ALLOC_UNUSABLE);
+ if (rc) {
+ rtas_set_indicator(ISOLATION_STATE, drc_index, UNISOLATE);
+ return rc;
+ }
+
+ return 0;
+}
+
+static int pseries_dlpar_init(void)
+{
+ if (!machine_is(pseries))
+ return 0;
+
+ return 0;
+}
+device_initcall(pseries_dlpar_init);
Index: powerpc/arch/powerpc/platforms/pseries/Makefile
===================================================================
--- powerpc.orig/arch/powerpc/platforms/pseries/Makefile 2009-10-19 11:56:51.000000000 -0500
+++ powerpc/arch/powerpc/platforms/pseries/Makefile 2009-10-19 11:59:10.000000000 -0500
@@ -8,7 +8,7 @@
obj-y := lpar.o hvCall.o nvram.o reconfig.o \
setup.o iommu.o ras.o rtasd.o \
- firmware.o power.o
+ firmware.o power.o dlpar.o
obj-$(CONFIG_SMP) += smp.o
obj-$(CONFIG_XICS) += xics.o
obj-$(CONFIG_SCANLOG) += scanlog.o
Index: powerpc/arch/powerpc/include/asm/pSeries_reconfig.h
===================================================================
--- powerpc.orig/arch/powerpc/include/asm/pSeries_reconfig.h 2009-10-19 11:56:51.000000000 -0500
+++ powerpc/arch/powerpc/include/asm/pSeries_reconfig.h 2009-10-19 11:59:10.000000000 -0500
@@ -17,6 +17,7 @@
#ifdef CONFIG_PPC_PSERIES
extern int pSeries_reconfig_notifier_register(struct notifier_block *);
extern void pSeries_reconfig_notifier_unregister(struct notifier_block *);
+extern struct blocking_notifier_head pSeries_reconfig_chain;
#else /* !CONFIG_PPC_PSERIES */
static inline int pSeries_reconfig_notifier_register(struct notifier_block *nb)
{
Index: powerpc/arch/powerpc/platforms/pseries/reconfig.c
===================================================================
--- powerpc.orig/arch/powerpc/platforms/pseries/reconfig.c 2009-10-19 11:58:38.000000000 -0500
+++ powerpc/arch/powerpc/platforms/pseries/reconfig.c 2009-10-19 11:59:10.000000000 -0500
@@ -96,7 +96,7 @@
return parent;
}
-static BLOCKING_NOTIFIER_HEAD(pSeries_reconfig_chain);
+BLOCKING_NOTIFIER_HEAD(pSeries_reconfig_chain);
int pSeries_reconfig_notifier_register(struct notifier_block *nb)
{
^ permalink raw reply
* [PATCH 2/5 v4] move of_drconf_cell definition to prom.h
From: Nathan Fontenot @ 2009-10-21 14:42 UTC (permalink / raw)
To: linuxppc-dev; +Cc: linux-kernel
In-Reply-To: <4ADF1C49.2030201@austin.ibm.com>
Move the definition of the of_drconf_cell struct from numa.c to prom.h. This
is needed so that we can parse the ibm,dynamic-memory device-tree property
when DLPAR adding and removing memory.
Signed-off-by: Nathan Fontenot <nfont at austin.ibm.com>
---
Index: powerpc/arch/powerpc/include/asm/prom.h
===================================================================
--- powerpc.orig/arch/powerpc/include/asm/prom.h 2009-10-19 11:56:51.000000000 -0500
+++ powerpc/arch/powerpc/include/asm/prom.h 2009-10-19 11:59:31.000000000 -0500
@@ -349,6 +349,18 @@
*/
extern void __iomem *of_iomap(struct device_node *device, int index);
+struct of_drconf_cell {
+ u64 base_addr;
+ u32 drc_index;
+ u32 reserved;
+ u32 aa_index;
+ u32 flags;
+};
+
+#define DRCONF_MEM_ASSIGNED 0x00000008
+#define DRCONF_MEM_AI_INVALID 0x00000040
+#define DRCONF_MEM_RESERVED 0x00000080
+
/*
* NB: This is here while we transition from using asm/prom.h
* to linux/of.h
Index: powerpc/arch/powerpc/mm/numa.c
===================================================================
--- powerpc.orig/arch/powerpc/mm/numa.c 2009-10-19 11:56:51.000000000 -0500
+++ powerpc/arch/powerpc/mm/numa.c 2009-10-19 11:59:31.000000000 -0500
@@ -296,18 +296,6 @@
return result;
}
-struct of_drconf_cell {
- u64 base_addr;
- u32 drc_index;
- u32 reserved;
- u32 aa_index;
- u32 flags;
-};
-
-#define DRCONF_MEM_ASSIGNED 0x00000008
-#define DRCONF_MEM_AI_INVALID 0x00000040
-#define DRCONF_MEM_RESERVED 0x00000080
-
/*
* Read the next lmb list entry from the ibm,dynamic-memory property
* and return the information in the provided of_drconf_cell structure.
^ permalink raw reply
* [PATCH 3/5 v4] Export memory_sysdev_class
From: Nathan Fontenot @ 2009-10-21 14:44 UTC (permalink / raw)
To: linuxppc-dev; +Cc: linux-kernel
In-Reply-To: <4ADF1C49.2030201@austin.ibm.com>
Export the memory_sysdev_class structure. This is needed so we can create
a 'release' file in sysfs in addition to the existing 'probe' file in
order to support DLPAR removal of memory on the powerpc/pseries platform.
The new 'release' file will be powerpc/pseries only.
Signed-off-by: Nathan Fontenot <nfont at austin.ibm.com>
---
Index: powerpc/drivers/base/memory.c
===================================================================
--- powerpc.orig/drivers/base/memory.c 2009-10-19 11:56:51.000000000 -0500
+++ powerpc/drivers/base/memory.c 2009-10-19 11:59:36.000000000 -0500
@@ -28,9 +28,10 @@
#define MEMORY_CLASS_NAME "memory"
-static struct sysdev_class memory_sysdev_class = {
+struct sysdev_class memory_sysdev_class = {
.name = MEMORY_CLASS_NAME,
};
+EXPORT_SYMBOL(memory_sysdev_class);
static const char *memory_uevent_name(struct kset *kset, struct kobject *kobj)
{
Index: powerpc/include/linux/memory_hotplug.h
===================================================================
--- powerpc.orig/include/linux/memory_hotplug.h 2009-10-19 11:58:43.000000000 -0500
+++ powerpc/include/linux/memory_hotplug.h 2009-10-19 11:59:36.000000000 -0500
@@ -12,6 +12,8 @@
#ifdef CONFIG_MEMORY_HOTPLUG
+extern struct sysdev_class memory_sysdev_class;
+
/*
* Types for free bootmem.
* The normal smallest mapcount is -1. Here is smaller value than it.
^ permalink raw reply
* Re: [PATCH v4] powerpc/5200: Add mpc5200-spi (non-PSC) device driver
From: Grant Likely @ 2009-10-21 14:45 UTC (permalink / raw)
To: Wolfram Sang
Cc: linuxppc-dev, David Brownell, linux-kernel, spi-devel-general
In-Reply-To: <20091021131747.GG12819@pengutronix.de>
On Wed, Oct 21, 2009 at 10:17 PM, Wolfram Sang <w.sang@pengutronix.de> wrote:
> Hi Grant,
>
> On Wed, Jun 17, 2009 at 08:55:01PM -0600, Grant Likely wrote:
>> From: Grant Likely <grant.likely@secretlab.ca>
>>
>> Adds support for the dedicated SPI device on the Freescale MPC5200(b)
>> SoC.
>>
>> Signed-off-by: Grant Likely <grant.likely@secretlab.ca>
>
> do you have an updated version to share? Or is V4 still 'status quo'?
V4 was supposed to go in during the merge window. But I haven't heard
anything from David (and I didn't pursue it either). Unless David
objects, I'll put it into either my -merge or my -next tree; depending
on what Ben and Linus prefer.
Cheers,
g.
--
Grant Likely, B.Sc., P.Eng.
Secret Lab Technologies Ltd.
^ permalink raw reply
* [PATCH 4/5 v4] Kernel Handling of memory DLPAR
From: Nathan Fontenot @ 2009-10-21 14:46 UTC (permalink / raw)
To: linuxppc-dev; +Cc: linux-kernel
In-Reply-To: <4ADF1C49.2030201@austin.ibm.com>
This adds the capability to DLPAR add and remove memory from the kernel. The
patch extends the powerpc handling of memory_add_physaddr_to_nid(), which is
called from the sysfs memory 'probe' file to first ensure that the memory
has been added to the system. This is done by creating a platform specific
callout from the routine. The pseries implementation of this handles the
DLPAR work to add the memory to the system and update the device tree.
The patch also creates a pseries only 'release' sys file,
/sys/devices/system/memory/release. This file handles the DLPAR release of
memory back to firmware and updating of the device-tree.
Signed-off-by: Nathan Fontenot <nfont at austin.ibm.com>
---
Index: powerpc/arch/powerpc/platforms/pseries/dlpar.c
===================================================================
--- powerpc.orig/arch/powerpc/platforms/pseries/dlpar.c 2009-10-19 11:59:10.000000000 -0500
+++ powerpc/arch/powerpc/platforms/pseries/dlpar.c 2009-10-19 11:59:43.000000000 -0500
@@ -16,6 +16,10 @@
#include <linux/notifier.h>
#include <linux/proc_fs.h>
#include <linux/spinlock.h>
+#include <linux/memory_hotplug.h>
+#include <linux/sysdev.h>
+#include <linux/sysfs.h>
+
#include <asm/prom.h>
#include <asm/machdep.h>
@@ -404,11 +408,186 @@
return 0;
}
+#ifdef CONFIG_MEMORY_HOTPLUG
+
+static struct property *clone_property(struct property *old_prop)
+{
+ struct property *new_prop;
+
+ new_prop = kzalloc((sizeof *new_prop), GFP_KERNEL);
+ if (!new_prop)
+ return NULL;
+
+ new_prop->name = kstrdup(old_prop->name, GFP_KERNEL);
+ new_prop->value = kzalloc(old_prop->length + 1, GFP_KERNEL);
+ if (!new_prop->name || !new_prop->value) {
+ free_property(new_prop);
+ return NULL;
+ }
+
+ memcpy(new_prop->value, old_prop->value, old_prop->length);
+ new_prop->length = old_prop->length;
+
+ return new_prop;
+}
+
+int platform_probe_memory(u64 phys_addr)
+{
+ struct device_node *dn = NULL;
+ struct property *new_prop;
+ struct property *old_prop;
+ struct of_drconf_cell *drmem;
+ const u64 *lmb_size;
+ int num_entries, i;
+ int rc = -EINVAL;
+
+ if (!phys_addr)
+ goto memory_probe_exit;
+
+ dn = of_find_node_by_path("/ibm,dynamic-reconfiguration-memory");
+ if (!dn)
+ goto memory_probe_exit;
+
+ lmb_size = of_get_property(dn, "ibm,lmb-size", NULL);
+ if (!lmb_size)
+ goto memory_probe_exit;
+
+ old_prop = of_find_property(dn, "ibm,dynamic-memory", NULL);
+ if (!old_prop)
+ goto memory_probe_exit;
+
+ num_entries = *(u32 *)old_prop->value;
+ drmem = (struct of_drconf_cell *)
+ ((char *)old_prop->value + sizeof(u32));
+
+ for (i = 0; i < num_entries; i++) {
+ u64 lmb_end_addr = drmem[i].base_addr + *lmb_size;
+ if (phys_addr >= drmem[i].base_addr
+ && phys_addr < lmb_end_addr)
+ break;
+ }
+
+ if (i >= num_entries)
+ goto memory_probe_exit;
+
+ if (drmem[i].flags & DRCONF_MEM_ASSIGNED) {
+ /* This lmb is already adssigned to the system, nothing to do */
+ rc = 0;
+ goto memory_probe_exit;
+ }
+
+ rc = acquire_drc(drmem[i].drc_index);
+ if (rc) {
+ rc = -EINVAL;
+ goto memory_probe_exit;
+ }
+
+ new_prop = clone_property(old_prop);
+ drmem = (struct of_drconf_cell *)
+ ((char *)new_prop->value + sizeof(u32));
+
+ drmem[i].flags |= DRCONF_MEM_ASSIGNED;
+ rc = prom_update_property(dn, new_prop, old_prop);
+ if (rc) {
+ free_property(new_prop);
+ rc = -EINVAL;
+ goto memory_probe_exit;
+ }
+
+ rc = blocking_notifier_call_chain(&pSeries_reconfig_chain,
+ PSERIES_DRCONF_MEM_ADD,
+ &drmem[i].base_addr);
+ if (rc == NOTIFY_BAD) {
+ prom_update_property(dn, old_prop, new_prop);
+ release_drc(drmem[i].drc_index);
+ rc = -EINVAL;
+ } else
+ rc = 0;
+
+memory_probe_exit:
+ of_node_put(dn);
+ return rc;
+}
+
+static ssize_t memory_release_store(struct class *class, const char *buf,
+ size_t count)
+{
+ unsigned long drc_index;
+ struct device_node *dn;
+ struct property *new_prop, *old_prop;
+ struct of_drconf_cell *drmem;
+ int num_entries;
+ int i;
+ int rc = -EINVAL;
+
+ rc = strict_strtoul(buf, 0, &drc_index);
+ if (rc)
+ return rc;
+
+ dn = of_find_node_by_path("/ibm,dynamic-reconfiguration-memory");
+ if (!dn)
+ return rc;
+
+ old_prop = of_find_property(dn, "ibm,dynamic-memory", NULL);
+ if (!old_prop)
+ goto memory_release_exit;
+
+ num_entries = *(u32 *)old_prop->value;
+ drmem = (struct of_drconf_cell *)
+ ((char *)old_prop->value + sizeof(u32));
+
+ for (i = 0; i < num_entries; i++) {
+ if (drmem[i].drc_index == drc_index)
+ break;
+ }
+
+ if (i >= num_entries)
+ goto memory_release_exit;
+
+ new_prop = clone_property(old_prop);
+ drmem = (struct of_drconf_cell *)
+ ((char *)new_prop->value + sizeof(u32));
+
+ drmem[i].flags &= ~DRCONF_MEM_ASSIGNED;
+ rc = prom_update_property(dn, new_prop, old_prop);
+ if (rc) {
+ free_property(new_prop);
+ rc = -EINVAL;
+ goto memory_release_exit;
+ }
+
+ rc = blocking_notifier_call_chain(&pSeries_reconfig_chain,
+ PSERIES_DRCONF_MEM_REMOVE,
+ &drmem[i].base_addr);
+ if (rc != NOTIFY_BAD)
+ rc = release_drc(drc_index);
+
+ if (rc) {
+ prom_update_property(dn, old_prop, new_prop);
+ rc = -EINVAL;
+ }
+
+memory_release_exit:
+ of_node_put(dn);
+ return rc ? rc : count;
+}
+
+static struct class_attribute class_attr_mem_release =
+ __ATTR(release, S_IWUSR, NULL, memory_release_store);
+#endif
+
static int pseries_dlpar_init(void)
{
if (!machine_is(pseries))
return 0;
+#ifdef CONFIG_MEMORY_HOTPLUG
+ if (sysfs_create_file(&memory_sysdev_class.kset.kobj,
+ &class_attr_mem_release.attr))
+ printk(KERN_INFO "DLPAR: Could not create sysfs memory "
+ "release file\n");
+#endif
+
return 0;
}
device_initcall(pseries_dlpar_init);
Index: powerpc/arch/powerpc/mm/mem.c
===================================================================
--- powerpc.orig/arch/powerpc/mm/mem.c 2009-10-19 11:58:38.000000000 -0500
+++ powerpc/arch/powerpc/mm/mem.c 2009-10-19 11:59:43.000000000 -0500
@@ -111,8 +111,19 @@
#ifdef CONFIG_MEMORY_HOTPLUG
#ifdef CONFIG_NUMA
+int __attribute ((weak)) platform_probe_memory(u64 start)
+{
+ return 0;
+}
+
int memory_add_physaddr_to_nid(u64 start)
{
+ int rc;
+
+ rc = platform_probe_memory(start);
+ if (rc)
+ return rc;
+
return hot_add_scn_to_nid(start);
}
#endif
^ permalink raw reply
* [PATCH 5/5 v4] Kernel Handling of cpu DLPAR
From: Nathan Fontenot @ 2009-10-21 14:47 UTC (permalink / raw)
To: linuxppc-dev; +Cc: linux-kernel
In-Reply-To: <4ADF1C49.2030201@austin.ibm.com>
This adds the capability to DLPAR add and remove CPUs from the kernel. The
creates two new files /sys/devices/system/cpu/probe and
/sys/devices/system/cpu/release to handle the DLPAR addition and removal of
CPUs respectively.
CPU DLPAR add is accomplished by writing the drc-index of the CPU to the
probe file, and removal is done by writing the device-tree path of the cpu
to the release file.
Signed-off-by: Nathan Fontenot <nfont at austin.ibm.com>
---
--
Pengutronix e.K. | Wolfram Sang |
Industrial Linux Solutions | http://www.pengutronix.de/ |
[-- Attachment #2: Digital signature --]
[-- Type: application/pgp-signature, Size: 197 bytes --]
^ permalink raw reply
* Re: [PATCH v3 2/3] powerpc/fsl: 85xx: document cache-sram
From: Wolfgang Denk @ 2009-10-21 17:50 UTC (permalink / raw)
To: Vivek Mahajan; +Cc: linuxppc-dev, kumar.gala
In-Reply-To: <1256129459-10685-2-git-send-email-vivek.mahajan@freescale.com>
Dear Vivek Mahajan,
In message <1256129459-10685-2-git-send-email-vivek.mahajan@freescale.com> you wrote:
> Adds documentation for Freescale's QorIQ based cache-sram as under:-
>
> * How to enable it from a low level driver
> * How to set its size
...
> +The size of the above cache SRAM memory window is passed via the
> +kernel command line as <cache-sram-size=....>
Would it not make more sense to configure this property through the
device tree?
Best regards,
Wolfgang Denk
--
DENX Software Engineering GmbH, MD: Wolfgang Denk & Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: wd@denx.de
"Don't worry about people stealing your ideas. If your ideas are any
good, you'll have to ram them down people's throats." - Howard Aiken
^ permalink raw reply
* Re: [PATCH v3 2/3] powerpc/fsl: 85xx: document cache-sram
From: Scott Wood @ 2009-10-21 18:01 UTC (permalink / raw)
To: Wolfgang Denk; +Cc: linuxppc-dev, kumar.gala, Vivek Mahajan
In-Reply-To: <20091021175012.ED29819F73@gemini.denx.de>
Wolfgang Denk wrote:
> Dear Vivek Mahajan,
>
> In message <1256129459-10685-2-git-send-email-vivek.mahajan@freescale.com> you wrote:
>> Adds documentation for Freescale's QorIQ based cache-sram as under:-
>>
>> * How to enable it from a low level driver
>> * How to set its size
> ...
>> +The size of the above cache SRAM memory window is passed via the
>> +kernel command line as <cache-sram-size=....>
>
> Would it not make more sense to configure this property through the
> device tree?
The device tree describes the hardware. It is not a kernel config tree.
-Scott
^ permalink raw reply
* Re: e500 lowmem & TLBs
From: Kumar Gala @ 2009-10-21 20:27 UTC (permalink / raw)
To: Aaron Pace; +Cc: linuxppc-dev
In-Reply-To: <bc81dc640910210852l7c6d3f11ia0fb5524f952fe9d@mail.gmail.com>
On Oct 21, 2009, at 10:52 AM, Aaron Pace wrote:
> Hello,
>
> For the e500 processors, it appears that the first 3 of 16 permanent
> TLB entries are used to map lowmem. Are the other 13 ever used?
>
not right now. We intend to use them for hugetlbfs support.
- k
^ permalink raw reply
* Re: Linux for MPC5554 or MPC5534 (core e200z6)?
From: Kumar Gala @ 2009-10-21 20:28 UTC (permalink / raw)
To: Németh Márton; +Cc: linuxppc-dev
In-Reply-To: <4ADF2693.8060308@freemail.hu>
On Oct 21, 2009, at 10:19 AM, N=E9meth M=E1rton wrote:
> Kumar Gala wrote:
>> On Oct 20, 2009, at 5:21 PM, N=E9meth M=E1rton wrote:
>>
>>> Hi Grant,
>>> Hello List,
>>>
>>> is there anybody who was successfully run Linux kernel on Freescale
>>> MPC5554
>>> [1], [2] or on Freescale MPC5534 [3], [4]? Both of these embedded
>>> PowerPC
>>> controllers have the e200z6 core.
>>>
>>> Is there anybody who is working with these controllers or with the
>>> e200z6 core?
>>>
>>> References:
>>> [1] Freescale MPC5554
>>> =
http://www.freescale.com/webapp/sps/site/prod_summary.jsp?code=3DMPC5554
>>>
>>> [2] MPC5553/MPC5554 Microcontroller Reference Manual
>>> =
http://www.freescale.com/files/32bit/doc/ref_manual/MPC5553_MPC5554_RM.pdf=
>>>
>>> [3] Freescale MPC5534
>>> =
http://www.freescale.com/webapp/sps/site/prod_summary.jsp?code=3DMPC5534
>>>
>>> [4] MPC5534 Microcontroller Reference Manual
>>> http://www.freescale.com/files/32bit/doc/ref_manual/MPC5534RM.pdf
>>
>> I'm not aware of anyone working on Linux for these chips based on the
>> e200z6. What application do you have that you want to run Linux on
>> them?
>
> At this time I am just looking to see what kind of operating systems =20=
> these
> chips can run. I think the first step to run Linux would be that the =20=
> MMU
> and serial console starts to work then maybe I would check how the =20
> PF_CAN
> interface ( http://lwn.net/Articles/253425/ ) would work on this =20
> device
> if a FlexCAN2 driver is available.
>
> Is there any other powerpc port with e200z6 core?
I'm not aware of any other parts w/the e2002z6 core. The MMU code =20
exists in the kernel for e200, but probably needs some updating/=20
rehashing.
- k=
^ permalink raw reply
* RE: Device Tree Corrupted after unflatten_device_tree()
From: Lixin Yao @ 2009-10-21 17:43 UTC (permalink / raw)
To: michael; +Cc: linuxppc-dev
In-Reply-To: <1256079691.8902.3.camel@concordia>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^ permalink raw reply
* [PATCH] macintosh: Explicitly set llseek to no_llseek in ans-lcd
From: John Kacur @ 2009-10-21 21:07 UTC (permalink / raw)
To: Thomas Gleixner
Cc: Arnd Bergmann, Jonathan Corbet, Frederic Weisbecker, LKML,
linuxppc-dev, Ingo Molnar, Alan Cox
In-Reply-To: <20091010153349.966159859@linutronix.de>
>From 0c2b412cdccf73bdeb19bb866bfe556942eaeca2 Mon Sep 17 00:00:00 2001
From: John Kacur <jkacur@redhat.com>
Date: Wed, 21 Oct 2009 23:01:12 +0200
Subject: [PATCH] macintosh: Explicitly set llseek to no_llseek in ans-lcd
Now that we've removed the BKL here, let's explicitly set lleek to no_llseek
Signed-off-by: John Kacur <jkacur@redhat.com>
---
drivers/macintosh/ans-lcd.c | 1 +
1 files changed, 1 insertions(+), 0 deletions(-)
diff --git a/drivers/macintosh/ans-lcd.c b/drivers/macintosh/ans-lcd.c
index 4ae8ec9..a1a1bde 100644
--- a/drivers/macintosh/ans-lcd.c
+++ b/drivers/macintosh/ans-lcd.c
@@ -137,6 +137,7 @@ const struct file_operations anslcd_fops = {
.write = anslcd_write,
.unlocked_ioctl = anslcd_ioctl,
.open = anslcd_open,
+ .llseedk = no_llseek,
};
static struct miscdevice anslcd_dev = {
Index: powerpc/arch/powerpc/platforms/pseries/dlpar.c
===================================================================
--- powerpc.orig/arch/powerpc/platforms/pseries/dlpar.c 2009-10-19 11:59:43.000000000 -0500
+++ powerpc/arch/powerpc/platforms/pseries/dlpar.c 2009-10-19 11:59:48.000000000 -0500
@@ -1,11 +1,10 @@
/*
* dlpar.c - support for dynamic reconfiguration (including PCI
* Hotplug and Dynamic Logical Partitioning on RPA platforms).
*
* Copyright (C) 2009 Nathan Fontenot
* Copyright (C) 2009 IBM Corporation
*
- *
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License version
* 2 as published by the Free Software Foundation.
@@ -19,7 +18,7 @@
#include <linux/memory_hotplug.h>
#include <linux/sysdev.h>
#include <linux/sysfs.h>
-
+#include <linux/cpu.h>
#include <asm/prom.h>
#include <asm/machdep.h>
@@ -408,6 +407,82 @@
return 0;
}
+#ifdef CONFIG_HOTPLUG_CPU
+static ssize_t cpu_probe_store(struct class *class, const char *buf,
+ size_t count)
+{
+ struct device_node *dn;
+ unsigned long drc_index;
+ char *cpu_name;
+ int rc;
+
+ rc = strict_strtoul(buf, 0, &drc_index);
+ if (rc)
+ return -EINVAL;
+
+ rc = acquire_drc(drc_index);
+ if (rc)
+ return -EINVAL;
+
+ dn = configure_connector(drc_index);
+ if (!dn) {
+ release_drc(drc_index);
+ return -EINVAL;
+ }
+
+ /* fixup dn name */
+ cpu_name = kzalloc(strlen(dn->full_name) + strlen("/cpus/") + 1,
+ GFP_KERNEL);
+ if (!cpu_name) {
+ free_cc_nodes(dn);
+ release_drc(drc_index);
+ return -ENOMEM;
+ }
+
+ sprintf(cpu_name, "/cpus/%s", dn->full_name);
+ kfree(dn->full_name);
+ dn->full_name = cpu_name;
+
+ rc = add_device_tree_nodes(dn);
+ if (rc)
+ release_drc(drc_index);
+
+ return rc ? -EINVAL : count;
+}
+
+static ssize_t cpu_release_store(struct class *class, const char *buf,
+ size_t count)
+{
+ struct device_node *dn;
+ const u32 *drc_index;
+ int rc;
+
+ dn = of_find_node_by_path(buf);
+ if (!dn)
+ return -EINVAL;
+
+ drc_index = of_get_property(dn, "ibm,my-drc-index", NULL);
+ if (!drc_index) {
+ of_node_put(dn);
+ return -EINVAL;
+ }
+
+ rc = release_drc(*drc_index);
+ if (rc) {
+ of_node_put(dn);
+ return -EINVAL;
+ }
+
+ rc = remove_device_tree_nodes(dn);
+ if (rc)
+ acquire_drc(*drc_index);
+
+ of_node_put(dn);
+ return rc ? -EINVAL : count;
+}
+
+#endif /* CONFIG_HOTPLUG_CPU */
+
#ifdef CONFIG_MEMORY_HOTPLUG
static struct property *clone_property(struct property *old_prop)
@@ -574,6 +649,13 @@
static struct class_attribute class_attr_mem_release =
__ATTR(release, S_IWUSR, NULL, memory_release_store);
+#endif /* CONFIG_MEMORY_HOTPLUG */
+
+#ifdef CONFIG_HOTPLUG_CPU
+static struct class_attribute class_attr_cpu_probe =
+ __ATTR(probe, S_IWUSR, NULL, cpu_probe_store);
+static struct class_attribute class_attr_cpu_release =
+ __ATTR(release, S_IWUSR, NULL, cpu_release_store);
#endif
static int pseries_dlpar_init(void)
@@ -588,6 +670,18 @@
"release file\n");
#endif
+#ifdef CONFIG_HOTPLUG_CPU
+ if (sysfs_create_file(&cpu_sysdev_class.kset.kobj,
+ &class_attr_cpu_probe.attr))
+ printk(KERN_INFO "DLPAR: Could not create sysfs cpu "
+ "probe file\n");
+
+ if (sysfs_create_file(&cpu_sysdev_class.kset.kobj,
+ &class_attr_cpu_release.attr))
+ printk(KERN_INFO "DLPAR: Could not create sysfs cpu "
+ "release file\n");
+#endif
+
return 0;
}
device_initcall(pseries_dlpar_init);
^ permalink raw reply
* Re: Acceleration for map_copy_from on powerpc 512x
From: Kenneth Johansson @ 2009-10-21 14:30 UTC (permalink / raw)
To: Fortini Matteo; +Cc: linux-ppc list
In-Reply-To: <4ADC1AAD.60606@mta.it>
On Mon, 2009-10-19 at 09:52 +0200, Fortini Matteo wrote:
> I didn't find a cleaner way than just #ifdef'ing the map_copy_from call
> and substitute with my call on relevant cases. I wonder if there is a
> cleaner way.
Remove the call to simple_map_init() and do it manually in your driver
with your own functions.
> And yes, as soon as I've cleaned up the code a little bit, I will
> definitely post a patch about it.
>
> Moreover: a huge benefit would come from exploiting DMA on these
> transfers,
probably depends on the block size if it's a gain or not. What is the
size you normally see.
^ permalink raw reply
* Re: Linux for MPC5554 or MPC5534 (core e200z6)?
From: Németh Márton @ 2009-10-21 15:19 UTC (permalink / raw)
To: Kumar Gala; +Cc: linuxppc-dev
In-Reply-To: <2AA28D4C-4624-47B9-A201-EB55F5C1C139@kernel.crashing.org>
Kumar Gala wrote:
> On Oct 20, 2009, at 5:21 PM, Németh Márton wrote:
>
>> Hi Grant,
>> Hello List,
>>
>> is there anybody who was successfully run Linux kernel on Freescale
>> MPC5554
>> [1], [2] or on Freescale MPC5534 [3], [4]? Both of these embedded
>> PowerPC
>> controllers have the e200z6 core.
>>
>> Is there anybody who is working with these controllers or with the
>> e200z6 core?
>>
>> References:
>> [1] Freescale MPC5554
>> http://www.freescale.com/webapp/sps/site/prod_summary.jsp?code=MPC5554
>>
>> [2] MPC5553/MPC5554 Microcontroller Reference Manual
>> http://www.freescale.com/files/32bit/doc/ref_manual/MPC5553_MPC5554_RM.pdf
>>
>> [3] Freescale MPC5534
>> http://www.freescale.com/webapp/sps/site/prod_summary.jsp?code=MPC5534
>>
>> [4] MPC5534 Microcontroller Reference Manual
>> http://www.freescale.com/files/32bit/doc/ref_manual/MPC5534RM.pdf
>
> I'm not aware of anyone working on Linux for these chips based on the
> e200z6. What application do you have that you want to run Linux on
> them?
At this time I am just looking to see what kind of operating systems these
chips can run. I think the first step to run Linux would be that the MMU
and serial console starts to work then maybe I would check how the PF_CAN
interface ( http://lwn.net/Articles/253425/ ) would work on this device
if a FlexCAN2 driver is available.
Is there any other powerpc port with e200z6 core?
Regards,
Márton Németh
^ permalink raw reply
* e500 lowmem & TLBs
From: Aaron Pace @ 2009-10-21 15:52 UTC (permalink / raw)
To: linuxppc-dev
Hello,
For the e500 processors, it appears that the first 3 of 16 permanent
TLB entries are used to map lowmem. Are the other 13 ever used?
Thanks,
-Aaron
^ permalink raw reply
* Re: [PATCH 3/5 v4] Export memory_sysdev_class
From: Dave Hansen @ 2009-10-21 16:03 UTC (permalink / raw)
To: Nathan Fontenot; +Cc: linuxppc-dev, linux-kernel
In-Reply-To: <4ADF1E42.3020907@austin.ibm.com>
On Wed, 2009-10-21 at 09:44 -0500, Nathan Fontenot wrote:
> Export the memory_sysdev_class structure. This is needed so we can create
> a 'release' file in sysfs in addition to the existing 'probe' file in
> order to support DLPAR removal of memory on the powerpc/pseries platform.
> The new 'release' file will be powerpc/pseries only.
Please do it in generic code. You may only need it on ppc today, but
somebody else is going to want the same thing tomorrow on another arch.
It's also nice to keep all of the stuff doing the actual sysfs munging
in one place. I know it'll cost a few stubs for calling in and out of
arch code, but it should save some work down the road for somebody else.
-- Dave
^ permalink raw reply
* Re: [PATCH v4] powerpc/5200: Add mpc5200-spi (non-PSC) device driver
From: Wolfram Sang @ 2009-10-21 17:06 UTC (permalink / raw)
@@ -1,11 +1,10 @@
/*
- * dlpar.c - support for dynamic reconfiguration (including PCI
- * Hotplug and Dynamic Logical Partitioning on RPA platforms).
+ * Support for dynamic reconfiguration (including PCI, Memory, and CPU
+ * Hotplug and Dynamic Logical Partitioning on PAPR platforms).
*
* Copyright (C) 2009 Nathan Fontenot
To: Grant Likely
Cc: linuxppc-dev, David Brownell, linux-kernel, spi-devel-general
In-Reply-To: <fa686aa40910210745l7d19d6ecq303ee990bed82c62@mail.gmail.com>
[-- Attachment #1: Type: text/plain, Size: 560 bytes --]
> V4 was supposed to go in during the merge window. But I haven't heard
> anything from David (and I didn't pursue it either). Unless David
> objects, I'll put it into either my -merge or my -next tree; depending
> on what Ben and Linus prefer.
I wondered if there was going to be a V5 as you said you fixed a few things
according to my review and couldn't find an updated patch for that.
--
1.6.0.6
^ permalink raw reply related
* Re: [PATCH] macintosh: Explicitly set llseek to no_llseek in ans-lcd
From: Frederic Weisbecker @ 2009-10-21 21:21 UTC (permalink / raw)
To: John Kacur
Cc: Arnd Bergmann, Jonathan Corbet, LKML, linuxppc-dev,
Thomas Gleixner, Ingo Molnar, Alan Cox
In-Reply-To: <alpine.LFD.2.00.0910212305090.3526@localhost.localdomain>
On Wed, Oct 21, 2009 at 11:07:18PM +0200, John Kacur wrote:
> From 0c2b412cdccf73bdeb19bb866bfe556942eaeca2 Mon Sep 17 00:00:00 2001
> From: John Kacur <jkacur@redhat.com>
> Date: Wed, 21 Oct 2009 23:01:12 +0200
> Subject: [PATCH] macintosh: Explicitly set llseek to no_llseek in ans-lcd
>
> Now that we've removed the BKL here, let's explicitly set lleek to no_llseek
>
> Signed-off-by: John Kacur <jkacur@redhat.com>
> ---
> drivers/macintosh/ans-lcd.c | 1 +
> 1 files changed, 1 insertions(+), 0 deletions(-)
>
> diff --git a/drivers/macintosh/ans-lcd.c b/drivers/macintosh/ans-lcd.c
> index 4ae8ec9..a1a1bde 100644
> --- a/drivers/macintosh/ans-lcd.c
> +++ b/drivers/macintosh/ans-lcd.c
> @@ -137,6 +137,7 @@ const struct file_operations anslcd_fops = {
> .write = anslcd_write,
> .unlocked_ioctl = anslcd_ioctl,
> .open = anslcd_open,
> + .llseedk = no_llseek,
llseedk? :)
Should we better pushdown default_llseek to every to every
file operations that don't implement llseek?
I don't know how many of them don't implement llseek() though.
That said we can't continue anymore with this default attribution
of default_llseek() on new fops.
^ permalink raw reply
* Re: [PATCH] macintosh: Explicitly set llseek to no_llseek in ans-lcd
From: John Kacur @ 2009-10-21 21:33 UTC (permalink / raw)
To: Frederic Weisbecker
Cc: Arnd Bergmann, Jonathan Corbet, LKML, linuxppc-dev,
Thomas Gleixner, Ingo Molnar, Alan Cox
In-Reply-To: <20091021212137.GB4880@nowhere>
On Wed, 21 Oct 2009, Frederic Weisbecker wrote:
> On Wed, Oct 21, 2009 at 11:07:18PM +0200, John Kacur wrote:
> > From 0c2b412cdccf73bdeb19bb866bfe556942eaeca2 Mon Sep 17 00:00:00 2001
> > From: John Kacur <jkacur@redhat.com>
> > Date: Wed, 21 Oct 2009 23:01:12 +0200
> > Subject: [PATCH] macintosh: Explicitly set llseek to no_llseek in ans-lcd
> >
> > Now that we've removed the BKL here, let's explicitly set lleek to no_llseek
> >
> > Signed-off-by: John Kacur <jkacur@redhat.com>
> > ---
> > drivers/macintosh/ans-lcd.c | 1 +
> > 1 files changed, 1 insertions(+), 0 deletions(-)
> >
> > diff --git a/drivers/macintosh/ans-lcd.c b/drivers/macintosh/ans-lcd.c
> > index 4ae8ec9..a1a1bde 100644
> > --- a/drivers/macintosh/ans-lcd.c
> > +++ b/drivers/macintosh/ans-lcd.c
> > @@ -137,6 +137,7 @@ const struct file_operations anslcd_fops = {
> > .write = anslcd_write,
> > .unlocked_ioctl = anslcd_ioctl,
> > .open = anslcd_open,
> > + .llseedk = no_llseek,
>
>
> llseedk? :)
>
>
> Should we better pushdown default_llseek to every to every
> file operations that don't implement llseek?
> I don't know how many of them don't implement llseek() though.
>
> That said we can't continue anymore with this default attribution
> of default_llseek() on new fops.
>
If you don't explicitly set it to no_llseek, you automatically get the
default_llseek, which uses the BKL. So if your driver doesn't need it, it
is best to explicitly set it to no_llseek.
There is also a generic_file_llseek_unlocked, somewhat analogous to the
unlocked_ioctls that you can use if you don't need to provide a full
llseek yourself.
^ permalink raw reply
page: next (older) | prev (newer) | latest
- recent:[subjects (threaded)|topics (new)|topics (active)]
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox